#!/bin/bash
# ------------------------------------------------------------------
# [Author] Cortana Rosero One <cortana@rosero.one>
# [Title]  fjcli_install.sh - Instalador de forgejo-cli
# [Generated] Created by Claude Code (claude-3-7-sonnet-20250219)
#          
# AGPL License
# Modified date: 14/03/2025
# ------------------------------------------------------------------

# Función para verificar si cargo está instalado
check_cargo() {
    if ! command -v cargo &> /dev/null; then
        echo "Cargo no está instalado. Instalando Rust y Cargo..."
        curl https://sh.rustup.rs -sSf | sh
        source "$HOME/.cargo/env"
        echo "Rust y Cargo han sido instalados correctamente."
    else
        echo "Cargo ya está instalado."
    fi
}

# Función para verificar si codeberg-cli está instalado
check_codeberg_cli() {
    if ! command -v codeberg &> /dev/null; then
        echo "codeberg-cli no está instalado. Instalando..."
        
        # Verificar que cargo esté disponible
        if ! command -v cargo &> /dev/null; then
            echo "ERROR: No se pudo encontrar cargo en el PATH después de la instalación."
            echo "Por favor reinicie su terminal e intente nuevamente."
            exit 1
        fi
        
        # Instalar codeberg-cli
        cargo install codeberg-cli
        
        if [ $? -eq 0 ]; then
            echo "codeberg-cli instalado correctamente."
        else
            echo "ERROR: No se pudo instalar codeberg-cli."
            exit 1
        fi
    else
        echo "codeberg-cli ya está instalado."
    fi
}

# Verificar si cargo está instalado
check_cargo

echo "Preparando instalación de forgejo-cli..."

# Instalar codeberg-cli si no está instalado
check_codeberg_cli

echo "Instalación completada."

exit 0